import { renderAtom } from "./atom/index.js";
import { renderJSON } from "./json/index.js";
import { renderRSS } from "./rss/index.js";
export class Feed {
    constructor(options) {
        this.options = options;
        this.items = [];
        this.categories = new Set();
        this._contributorKeys = new Set();
        this.contributors = [];
        /**
         * Add a feed item
         */
        this.addItem = (item) => {
            this.items.push(item);
        };
        /**
         * Add a category
         */
        this.addCategory = (category) => {
            this.categories.add(category);
        };
        /**
         * Add a contributor
         */
        this.addContributor = (contributor) => {
            // use keys to avoid adding same contributor
            const key = contributor.email || contributor.name;
            if (key && !this._contributorKeys.has(key)) {
                this._contributorKeys.add(key);
                this.contributors.push(contributor);
            }
        };
        /**
         * Returns a Atom 1.0 feed
         */
        this.atom = () => renderAtom(this);
        /**
         * Returns a RSS 2.0 feed
         */
        this.rss = () => renderRSS(this);
        /**
         * Returns a JSON 1.1 feed
         */
        this.json = () => renderJSON(this);
    }
}
//# sourceMappingURL=feed.js.map