import { chalk } from "@vuepress/utils";
import { convertOptions } from "./compact/index.js";
import { checkOutput, ensureHostName, getFeedOptions } from "./options.js";
import { injectLinkstoHead } from "./injectHead.js";
import { FeedGenerator } from "./generator.js";
import { logger } from "./utils.js";
export const feedPlugin = (options, legacy = false) => (app) => {
    // TODO: Remove this in v2 stable
    if (legacy)
        convertOptions(options);
    if (app.env.isDebug)
        logger.info(`Options: ${options.toString()}`);
    const plugin = {
        name: "vuepress-plugin-feed2",
    };
    if (!ensureHostName(options)) {
        logger.error(`Option ${chalk.magenta("hostname")} is required!`);
        return plugin;
    }
    if (!checkOutput(options)) {
        logger.info("No requested output, the plugin won’t start!");
        return plugin;
    }
    const feedOptions = getFeedOptions(app, options);
    return {
        ...plugin,
        onPrepared: (app) => injectLinkstoHead(app, feedOptions),
        onGenerated: async (app) => {
            await new FeedGenerator(app, feedOptions).generateFeed();
        },
    };
};
//# sourceMappingURL=plugin.js.map